@@ -1,10 +1,8 @@
-use crate::{prelude::*, Image, SamplingOptions};
 use crate::{
-    AlphaType, Color, ColorSpace, ColorType, IPoint, IRect, ISize, ImageInfo, Matrix, Paint,
-    PixelRef, Pixmap, Shader, TileMode,
+    prelude::*, AlphaType, Color, ColorSpace, ColorType, IPoint, IRect, ISize, Image, ImageInfo,
+    Matrix, Paint, PixelRef, Pixmap, SamplingOptions, Shader, TileMode,
 };
-use skia_bindings as sb;
-use skia_bindings::SkBitmap;
+use skia_bindings::{self as sb, SkBitmap};
 use std::{ffi, fmt, ptr};
 
 /// [Bitmap] describes a two-dimensional raster pixel array. [Bitmap] is built on [ImageInfo],
@@ -617,7 +615,7 @@ impl Bitmap {
     /// - [PixelRef] is `nullptr`
     /// - subset does not intersect [Self::bounds()]
     ///
-    /// example: https://fiddle.skia.org/c/@Bitmap_extractSubset
+    /// example: <https://fiddle.skia.org/c/@Bitmap_extractSubset>
     pub fn extract_subset(&self, dst: &mut Self, subset: impl AsRef<IRect>) -> bool {
         unsafe {
             self.native()
@@ -688,7 +686,7 @@ impl Bitmap {
     ///
     /// pixmap contents become invalid on any future change to [Bitmap].
     ///
-    /// example: https://fiddle.skia.org/c/@Bitmap_peekPixels
+    /// example: <https://fiddle.skia.org/c/@Bitmap_peekPixels>
     pub fn peek_pixels(&self) -> Option<Borrows<Pixmap>> {
         let mut pixmap = Pixmap::default();
         unsafe { self.native().peekPixels(pixmap.native_mut()) }
