@@ -74,48 +74,48 @@ impl IRect {
         }
     }
 
-    pub fn left(&self) -> i32 {
+    pub const fn left(&self) -> i32 {
         self.left
     }
 
-    pub fn top(&self) -> i32 {
+    pub const fn top(&self) -> i32 {
         self.top
     }
 
-    pub fn right(&self) -> i32 {
+    pub const fn right(&self) -> i32 {
         self.right
     }
 
-    pub fn bottom(&self) -> i32 {
+    pub const fn bottom(&self) -> i32 {
         self.bottom
     }
 
-    pub fn x(&self) -> i32 {
+    pub const fn x(&self) -> i32 {
         self.left
     }
 
-    pub fn y(&self) -> i32 {
+    pub const fn y(&self) -> i32 {
         self.top
     }
 
-    pub fn width(&self) -> i32 {
+    pub const fn width(&self) -> i32 {
         sk32::can_overflow_sub(self.right, self.left)
     }
 
-    pub fn height(&self) -> i32 {
+    pub const fn height(&self) -> i32 {
         sk32::can_overflow_sub(self.bottom, self.top)
     }
 
-    pub fn size(&self) -> ISize {
-        (self.width(), self.height()).into()
+    pub const fn size(&self) -> ISize {
+        ISize::new(self.width(), self.height())
     }
 
-    pub fn width_64(&self) -> i64 {
-        i64::from(self.right) - i64::from(self.left)
+    pub const fn width_64(&self) -> i64 {
+        self.right as i64 - self.left as i64
     }
 
-    pub fn height_64(&self) -> i64 {
-        i64::from(self.bottom) - i64::from(self.top)
+    pub const fn height_64(&self) -> i64 {
+        self.bottom as i64 - self.top as i64
     }
 
     pub fn is_empty_64(&self) -> bool {
@@ -416,27 +416,27 @@ impl Rect {
         !accum.is_nan()
     }
 
-    pub fn x(&self) -> scalar {
+    pub const fn x(&self) -> scalar {
         self.left
     }
 
-    pub fn y(&self) -> scalar {
+    pub const fn y(&self) -> scalar {
         self.top
     }
 
-    pub fn left(&self) -> scalar {
+    pub const fn left(&self) -> scalar {
         self.left
     }
 
-    pub fn top(&self) -> scalar {
+    pub const fn top(&self) -> scalar {
         self.top
     }
 
-    pub fn right(&self) -> scalar {
+    pub const fn right(&self) -> scalar {
         self.right
     }
 
-    pub fn bottom(&self) -> scalar {
+    pub const fn bottom(&self) -> scalar {
         self.bottom
     }
 
@@ -535,6 +535,7 @@ impl Rect {
         *self = Self::from_iwh(width, height)
     }
 
+    #[must_use]
     pub fn with_offset(&self, d: impl Into<Vector>) -> Self {
         let d = d.into();
         Self::new(
@@ -545,6 +546,7 @@ impl Rect {
         )
     }
 
+    #[must_use]
     pub fn with_inset(&self, d: impl Into<Vector>) -> Self {
         let d = d.into();
         Self::new(
@@ -555,6 +557,7 @@ impl Rect {
         )
     }
 
+    #[must_use]
     pub fn with_outset(&self, d: impl Into<Vector>) -> Self {
         let d = d.into();
         Self::new(
@@ -573,6 +576,7 @@ impl Rect {
         *self = self.with_offset_to(new_p)
     }
 
+    #[must_use]
     pub fn with_offset_to(&self, new_p: impl Into<Point>) -> Self {
         let new_p = new_p.into();
         Self::new(new_p.x, new_p.y, new_p.x - self.left, new_p.y - self.top)
