@@ -199,9 +199,10 @@ impl Surface {
         ))
     }
 
+    #[allow(clippy::missing_safety_doc)]
     #[cfg(feature = "metal")]
     #[deprecated(since = "0.36.0", note = "use from_mtk_view()")]
-    pub fn from_ca_mtk_view(
+    pub unsafe fn from_ca_mtk_view(
         context: &mut gpu::DirectContext,
         mtk_view: gpu::mtl::Handle,
         origin: gpu::SurfaceOrigin,
@@ -221,8 +222,9 @@ impl Surface {
         )
     }
 
+    #[allow(clippy::missing_safety_doc)]
     #[cfg(feature = "metal")]
-    pub fn from_mtk_view(
+    pub unsafe fn from_mtk_view(
         context: &mut gpu::RecordingContext,
         mtk_view: gpu::mtl::Handle,
         origin: gpu::SurfaceOrigin,
@@ -231,17 +233,15 @@ impl Surface {
         color_space: impl Into<Option<crate::ColorSpace>>,
         surface_props: Option<&SurfaceProps>,
     ) -> Option<Self> {
-        Self::from_ptr(unsafe {
-            sb::C_SkSurface_MakeFromMTKView(
-                context.native_mut(),
-                mtk_view,
-                origin,
-                sample_count.into().unwrap_or(0).try_into().unwrap(),
-                color_type.into_native(),
-                color_space.into().into_ptr_or_null(),
-                surface_props.native_ptr_or_null(),
-            )
-        })
+        Self::from_ptr(sb::C_SkSurface_MakeFromMTKView(
+            context.native_mut(),
+            mtk_view,
+            origin,
+            sample_count.into().unwrap_or(0).try_into().unwrap(),
+            color_type.into_native(),
+            color_space.into().into_ptr_or_null(),
+            surface_props.native_ptr_or_null(),
+        ))
     }
 }
 
@@ -471,6 +471,11 @@ impl Surface {
         }
     }
 
+    #[cfg(feature = "gpu")]
+    pub fn resolve_msaa(&mut self) {
+        unsafe { self.native_mut().resolveMSAA() }
+    }
+
     // After deprecated since 0.30.0 (m85), the default flush() behavior changed in m86.
     // For more information, take a look at the documentation in Skia's SkSurface.h
     #[cfg(feature = "gpu")]
